<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fa">
<context>
    <name>FeatherNotes::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="171"/>
        <source>License</source>
        <translation>مجوز</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::ColorLabel</name>
    <message>
        <location filename="../../colorLabel.cpp" line="31"/>
        <source>Click to change color.</source>
        <translation>برای تغییر رنگ کلیک کنید.</translation>
    </message>
    <message>
        <location filename="../../colorLabel.cpp" line="53"/>
        <source>Select Color</source>
        <translation>انتخاب رنگ</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::FN</name>
    <message>
        <location filename="../../fn.ui" line="14"/>
        <source>FeatherNotes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="65"/>
        <source>Next (F3)</source>
        <translation>بعدی (F3)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="68"/>
        <source>F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="81"/>
        <source>Previous (F4)</source>
        <translation>قبلی (F4)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="84"/>
        <source>F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="100"/>
        <source>Search...</source>
        <translation>جستجو...</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="115"/>
        <source>Search only in names (Ctrl+Shift+F7)</source>
        <translation>جستجو تنها در نامها (Ctrl+Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="118"/>
        <source>Ctrl+Shift+F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="128"/>
        <source>Search only in tags (Shift+F7)</source>
        <translation>جستجو تنها در برچسبها (Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="131"/>
        <source>Shift+F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="144"/>
        <source>Search in all nodes (F7)</source>
        <translation>جستجو در همه‌ی شاخه‌ها (F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="147"/>
        <source>F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="186"/>
        <source>Whole Word (F6)</source>
        <translation>تمام واژه (F6)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="189"/>
        <source>Whole Word</source>
        <translation>تمام واژه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="192"/>
        <source>F6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="167"/>
        <source>Match Case (F5)</source>
        <translation>سازگار با بزرگی و کوچکی حروف (F5)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="170"/>
        <source>Match Case</source>
        <translation>سازگار با بزرگی و کوچکی حروف</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="173"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="219"/>
        <source>&amp;File</source>
        <translation>فايل</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="223"/>
        <source>Recenl&amp;y Opened</source>
        <translation>تازه باز شده</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="245"/>
        <source>&amp;Edit</source>
        <translation>ويرايش</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="264"/>
        <source>For&amp;mat</source>
        <translation>قالب</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="296"/>
        <source>&amp;Tree</source>
        <translation>شاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="320"/>
        <source>&amp;Options</source>
        <translation>گزينه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="334"/>
        <source>&amp;Search</source>
        <translation>جستجو</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="341"/>
        <location filename="../../fn.ui" line="987"/>
        <source>&amp;Help</source>
        <translation>راهنما</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="436"/>
        <source>Find:</source>
        <translation>يافتن:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="443"/>
        <source>Replace with:</source>
        <translation>جايگزينی با:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="456"/>
        <source>To be replaced</source>
        <translation>جايگزين شود</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="469"/>
        <source>Replacing text</source>
        <translation>متن جايگزين</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="479"/>
        <source>Previous (F9)</source>
        <translation>قبلی (F9)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="482"/>
        <source>F9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="495"/>
        <source>Next (F8)</source>
        <translation>بعدی (F8)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="498"/>
        <source>F8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="511"/>
        <source>Replace all (F10)</source>
        <translation>جايگزينی همه (F10)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="514"/>
        <source>F10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="531"/>
        <source>&amp;Save</source>
        <translation>ذخيره‌سازی</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="534"/>
        <location filename="../../fn.cpp" line="1018"/>
        <source>Save</source>
        <translation>ذخيره‌سازی</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="537"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="542"/>
        <location filename="../../fn.cpp" line="678"/>
        <source>&amp;Open</source>
        <translation>بازکردن</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="545"/>
        <source>Open a file</source>
        <translation>بازکردن فايل</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="548"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="556"/>
        <source>&amp;Undo</source>
        <translation>بازگشت</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="559"/>
        <source>Undo</source>
        <translation>بازگشت</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="562"/>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="570"/>
        <source>&amp;Redo</source>
        <translation>تکرار</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="573"/>
        <source>Redo</source>
        <translation>تکرار</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="576"/>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="584"/>
        <source>&amp;Find</source>
        <translation>يافتن</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="587"/>
        <source>Show/hide searchbar</source>
        <translation>آشکار يا پنهان کردن قسمت جستجو</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="590"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="598"/>
        <source>&amp;Clear All Formats</source>
        <translation>پاک کردن همه‌ی قالبها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="601"/>
        <source>Clear all formats</source>
        <translation>پاک کردن همه‌ی قالبها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="604"/>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="615"/>
        <source>&amp;Bold</source>
        <translation>ضخيم</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="618"/>
        <source>Bold</source>
        <translation>ضخيم</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="621"/>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="632"/>
        <source>&amp;Italic</source>
        <translation>مورب</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="635"/>
        <source>Italic</source>
        <translation>مورب</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="638"/>
        <source>Ctrl+I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="649"/>
        <source>&amp;Underline</source>
        <translation>خط زيرين</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="652"/>
        <source>Underline</source>
        <translation>خط زيرين</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="655"/>
        <source>Ctrl+U</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="666"/>
        <source>&amp;Strike Through</source>
        <translation>خط ميانی</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="669"/>
        <source>Strike through</source>
        <translation>خط ميانی</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="672"/>
        <source>Ctrl+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="680"/>
        <source>Te&amp;xt Color</source>
        <translation>رنگ متن</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="683"/>
        <source>Text color</source>
        <translation>رنگ متن</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="686"/>
        <source>Alt+Shift+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="694"/>
        <source>Back&amp;ground Color</source>
        <translation>رنگ پسزمينه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="697"/>
        <source>Background color</source>
        <translation>رنگ پسزمينه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="700"/>
        <source>Alt+Shift+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="705"/>
        <source>Options</source>
        <translation>گزينه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="710"/>
        <location filename="../../fn.cpp" line="677"/>
        <source>&amp;New Note</source>
        <translation>شاخه‌ی نو</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="713"/>
        <source>Ctrl+Alt+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="721"/>
        <source>Save &amp;As</source>
        <translation>ذخيره‌سازی به عنوان</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="724"/>
        <source>Ctrl+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="732"/>
        <source>&amp;Print</source>
        <translation>چاپ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="735"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="743"/>
        <source>P&amp;rint with Sub-Nodes</source>
        <translation>چاپ با زيرشاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="751"/>
        <source>Set Pass&amp;word</source>
        <translation>انتخاب گذرواژه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="756"/>
        <location filename="../../fn.cpp" line="680"/>
        <source>&amp;Quit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="759"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="767"/>
        <source>&amp;Cut</source>
        <translation>بريدن</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="770"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="778"/>
        <source>C&amp;opy</source>
        <translation>رونوشت</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="781"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="789"/>
        <source>&amp;Paste</source>
        <translation>چسباندن</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="792"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="800"/>
        <source>&amp;Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="808"/>
        <source>&amp;Select All</source>
        <translation>انتخاب همه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="811"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="819"/>
        <source>E&amp;mbed Image</source>
        <translation>گذاشتن تصوير</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="822"/>
        <location filename="../../fn.cpp" line="4414"/>
        <source>Embed Image</source>
        <translation>گذاشتن تصوير</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="825"/>
        <source>Ctrl+Alt+Shift+I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="833"/>
        <source>E&amp;xpand All</source>
        <translation>باز کردن شاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="836"/>
        <source>Ctrl+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="844"/>
        <source>Collap&amp;se All</source>
        <translation>بستن شاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="847"/>
        <source>Ctrl+Shift+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="855"/>
        <source>&amp;Append Sibling</source>
        <translation>افزودن شاخه‌ی موازی</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="858"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="866"/>
        <source>Append &amp;Child</source>
        <translation>افزودن زيرشاخه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="869"/>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="877"/>
        <source>&amp;Delete Node</source>
        <translation>حذف شاخه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="880"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="888"/>
        <source>Move &amp;Up</source>
        <translation>بالا بردن</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="891"/>
        <source>Alt+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="899"/>
        <source>Move Do&amp;wn</source>
        <translation>پايين آوردن</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="902"/>
        <source>Alt+Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="910"/>
        <source>Re&amp;name Node</source>
        <translation>تغيير نام</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="913"/>
        <source>Ctrl+Shift+R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="918"/>
        <source>Tree Pr&amp;operties</source>
        <translation>ويژگی‌های شاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="921"/>
        <source>Ctrl+Shift+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="929"/>
        <source>Document &amp;Font</source>
        <translation>قلم سند</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="943"/>
        <source>&amp;Wrap Lines</source>
        <translation>قالب‌بندی خطها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="946"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="960"/>
        <source>&amp;Auto-Indentation</source>
        <translation>دندانه‌گذاری خودکار</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="963"/>
        <source>Ctrl+Shift+I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="968"/>
        <source>&amp;Preferences</source>
        <translation>تنظيمها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="971"/>
        <source>Ctrl+Shift+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="979"/>
        <source>Find and &amp;Replace</source>
        <translation>يافتن و جايگزينی</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="982"/>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="990"/>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="995"/>
        <source>&amp;About</source>
        <translation>درباره</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1003"/>
        <source>Pr&amp;int All Nodes</source>
        <translation>چاپ همه‌ی شاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1014"/>
        <source>Superscrip&amp;t</source>
        <translation>بالانويس</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1017"/>
        <source>Superscript</source>
        <translation>بالانويس</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1020"/>
        <source>Alt+Shift+U</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1031"/>
        <source>Subscri&amp;pt</source>
        <translation>زيرنويس</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1034"/>
        <source>Subscript</source>
        <translation>زيرنويس</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1037"/>
        <source>Alt+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1048"/>
        <source>C&amp;enter</source>
        <translation>وسط</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1051"/>
        <source>Align center</source>
        <translation>تراز کردن در وسط</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1054"/>
        <source>Alt+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1065"/>
        <location filename="../../fn.cpp" line="2217"/>
        <source>&amp;Right</source>
        <translation>راست</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1068"/>
        <source>Align right</source>
        <translation>تراز کردن به راست</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1071"/>
        <source>Alt+Shift+Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1082"/>
        <location filename="../../fn.cpp" line="2211"/>
        <source>&amp;Left</source>
        <translation>چپ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1085"/>
        <source>Align left</source>
        <translation>تراز کردن به چپ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1088"/>
        <source>Alt+Shift+Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1099"/>
        <source>&amp;Justify</source>
        <translation>تراز کردن دوسويه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1102"/>
        <source>Justify</source>
        <translation>تراز کردن دوسويه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1105"/>
        <source>Alt+Shift+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1113"/>
        <source>&amp;Prepend Sibling</source>
        <translation>افزودن شاخه‌ی موازی از بالا</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1116"/>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1124"/>
        <source>Move &amp;Left</source>
        <translation>جابجايی به چپ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1127"/>
        <source>Alt+Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1135"/>
        <source>Move &amp;Right</source>
        <translation>جابجايی به راست</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1138"/>
        <source>Alt+Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1146"/>
        <source>h&amp;2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1149"/>
        <source>Header 2</source>
        <translation>سرخط ۲</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1152"/>
        <source>Ctrl+2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1160"/>
        <source>h&amp;1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1163"/>
        <source>Header 1</source>
        <translation>سرخط ۱</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1166"/>
        <source>Ctrl+1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1174"/>
        <source>h&amp;3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1177"/>
        <source>Header 3</source>
        <translation>سرخط ۳</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1180"/>
        <source>Ctrl+3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1188"/>
        <source>&amp;Node Font</source>
        <translation>قلم شاخه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1191"/>
        <source>Node Font</source>
        <translation>قلم شاخه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1196"/>
        <source>Scale I&amp;mage(s)</source>
        <translation>تغيير اندازه‌ی تصوير(ها)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1204"/>
        <source>Paste &amp;HTML</source>
        <translation>چسباندن HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1207"/>
        <source>Ctrl+Shift+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1215"/>
        <source>&amp;Tags</source>
        <translation>برچسبها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1218"/>
        <source>Ctrl+Shift+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1226"/>
        <source>Insert Lin&amp;k</source>
        <translation>گذاشتن پيوند</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1229"/>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1234"/>
        <source>C&amp;opy Link</source>
        <translation>رونويسی از پيوند</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1242"/>
        <source>I&amp;nsert Table</source>
        <translation>گذاشتن جدول</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1245"/>
        <source>Ctrl+Alt+Shift+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1250"/>
        <source>Append Row</source>
        <translation>افزودن رديف</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1255"/>
        <source>Delete Row</source>
        <translation>حذف رديف</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1260"/>
        <source>Append Column</source>
        <translation>افزودن ستون</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1265"/>
        <source>Delete Column</source>
        <translation>حذف ستون</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1270"/>
        <source>Merge Cells</source>
        <translation>ادغام خانه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1275"/>
        <source>Prepend Row</source>
        <translation>افزودن رديف از بالا</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1280"/>
        <source>Prepend Column</source>
        <translation>افزودن ستون از پس</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1288"/>
        <source>Export &amp;HTML</source>
        <translation>صدور به HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1293"/>
        <source>Save Ima&amp;ge(s)</source>
        <translation>ذخيره‌سازی تصوير(ها)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1304"/>
        <source>RTL</source>
        <translation>راست به چپ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1307"/>
        <source>Ctrl+Alt+Shift+Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1318"/>
        <source>LTR</source>
        <translation>چپ به راست</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1321"/>
        <source>Ctrl+Alt+Shift+Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1326"/>
        <location filename="../../fn.ui" line="1329"/>
        <source>Menu</source>
        <translation>منو</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1337"/>
        <source>Node &amp;Icon</source>
        <translation>شمايل شاخه</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1340"/>
        <source>Ctrl+Shift+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1345"/>
        <location filename="../../fn.ui" line="1348"/>
        <source>Check Spelling</source>
        <translation>بررسی تلفظ</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1351"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1356"/>
        <source>Document &amp;Colors</source>
        <translation>رنگهای سند</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1364"/>
        <location filename="../../fn.ui" line="1367"/>
        <source>Paste Date and Time</source>
        <translation>چسباندن تاريخ و زمان</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1372"/>
        <source>&amp;Clear</source>
        <translation>پاکسازی</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3001"/>
        <source>Node Icon</source>
        <translation>شمايل شاخه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="674"/>
        <source>&amp;Raise/Hide</source>
        <translation>پيش آوردن يا پنهان کردن</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="914"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;شاخه‌ی نو؟&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="915"/>
        <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;آيا می‌خواهيد اين سند را ترک کنيد&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;و يک سند خالی بسازيد؟&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="918"/>
        <location filename="../../fn.cpp" line="2832"/>
        <location filename="../../fn.cpp" line="4777"/>
        <source>Yes</source>
        <translation>آری</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="919"/>
        <location filename="../../fn.cpp" line="2833"/>
        <location filename="../../fn.cpp" line="4778"/>
        <source>No</source>
        <translation>نه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1010"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;ذخيره‌سازی تغييرات؟&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1012"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;سند تغيير يافته است.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1014"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;سند حذف شده است.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1019"/>
        <source>Discard changes</source>
        <translation>ناديده گرفتن تغييرات</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1020"/>
        <location filename="../../fn.cpp" line="2950"/>
        <location filename="../../fn.cpp" line="3044"/>
        <location filename="../../fn.cpp" line="3317"/>
        <location filename="../../fn.cpp" line="4353"/>
        <location filename="../../fn.cpp" line="4438"/>
        <location filename="../../fn.cpp" line="4616"/>
        <location filename="../../fn.cpp" line="4879"/>
        <location filename="../../fn.cpp" line="5827"/>
        <location filename="../../fn.cpp" line="6106"/>
        <location filename="../../fn.cpp" line="6204"/>
        <source>Cancel</source>
        <translation>لغو</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1484"/>
        <source>Open file...</source>
        <translation>بازکردن فايل...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1661"/>
        <location filename="../../fn.cpp" line="5953"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;قابل ذخيره‌سازی نيست!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3613"/>
        <source>Close</source>
        <translation>بستن</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1761"/>
        <location filename="../../fn.cpp" line="1784"/>
        <source>Save As...</source>
        <translation>ذخيره‌سازی به عنوان...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1486"/>
        <location filename="../../fn.cpp" line="1763"/>
        <location filename="../../fn.cpp" line="1786"/>
        <source>FeatherNotes documents</source>
        <translation>سندهای FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1486"/>
        <location filename="../../fn.cpp" line="1763"/>
        <location filename="../../fn.cpp" line="1786"/>
        <location filename="../../fn.cpp" line="3033"/>
        <location filename="../../fn.cpp" line="4537"/>
        <location filename="../../fn.cpp" line="4808"/>
        <source>All Files</source>
        <translation>همه‌ی فايلها</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2829"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;حذف اين شاخه؟&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2830"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;هشدار!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;اين کار بازگشت‌پذير نيست.&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2936"/>
        <source>Tags</source>
        <translation>برچسبها</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2951"/>
        <location filename="../../fn.cpp" line="3045"/>
        <location filename="../../fn.cpp" line="3318"/>
        <location filename="../../fn.cpp" line="4355"/>
        <location filename="../../fn.cpp" line="4439"/>
        <location filename="../../fn.cpp" line="4617"/>
        <location filename="../../fn.cpp" line="4880"/>
        <location filename="../../fn.cpp" line="5829"/>
        <location filename="../../fn.cpp" line="6107"/>
        <location filename="../../fn.cpp" line="6205"/>
        <source>OK</source>
        <translation>تاييد</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3033"/>
        <location filename="../../fn.cpp" line="4537"/>
        <location filename="../../fn.cpp" line="4808"/>
        <source>Image Files</source>
        <translation>فايلهای تصويری</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3125"/>
        <location filename="../../fn.cpp" line="3158"/>
        <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;شاخه‌های اصلی:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;همه‌ی شاخه‌ها:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3131"/>
        <location filename="../../fn.cpp" line="3164"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
        <translation>&lt;b&gt;يادداشت:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;شاخه‌های اصلی:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;همه‌ی شاخه‌ها:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3600"/>
        <source>%1 Matches</source>
        <translation>%1 نمونه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3602"/>
        <source>One Match</source>
        <translation>يک نمونه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3604"/>
        <location filename="../../fn.cpp" line="3971"/>
        <source>No Match</source>
        <translation>هيچ نمونه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3770"/>
        <location filename="../../fn.cpp" line="3823"/>
        <source>Replacement</source>
        <translation>جايگذاری</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4078"/>
        <source>No Replacement</source>
        <translation>بدون جايگذاری</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4080"/>
        <source>One Replacement</source>
        <translation>يک جايگذاری</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4083"/>
        <source>%1 Replacements</source>
        <translation>%1 جايگذاری</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4341"/>
        <source>Insert Link</source>
        <translation>گذاشتن پيوند</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6050"/>
        <source>HTML Files</source>
        <translation>فايلهای HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3009"/>
        <location filename="../../fn.cpp" line="4423"/>
        <source>Image path</source>
        <translation>مسير تصوير</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3013"/>
        <location filename="../../fn.cpp" line="4427"/>
        <source>Open image</source>
        <translation>باز کردن تصوير</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4435"/>
        <location filename="../../fn.cpp" line="4613"/>
        <source>Scaling percentage</source>
        <translation>درصد تغيير اندازه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3031"/>
        <location filename="../../fn.cpp" line="4535"/>
        <source>Open Image...</source>
        <translation>باز کردن تصوير...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="649"/>
        <source>System tray is not available.
Please disable tray in Preferences.</source>
        <translatorcomment>جعبه‌ی وظايف موجود نيست.
لطفا آن را در بخش تنظيمها غير فعال کنيد.</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="965"/>
        <source>New Node</source>
        <translation>شاخه‌ی نو</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1662"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;قابل باز کردن نيست!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1743"/>
        <location filename="../../fn.cpp" line="5668"/>
        <location filename="../../fn.cpp" line="5677"/>
        <location filename="../../fn.cpp" line="5816"/>
        <location filename="../../fn.cpp" line="6007"/>
        <location filename="../../fn.cpp" line="6016"/>
        <location filename="../../fn.cpp" line="6043"/>
        <source>Untitled</source>
        <translation>بی‌نام</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2210"/>
        <source>Align Table</source>
        <translation>تراز کردن جدول</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2223"/>
        <source>&amp;Center</source>
        <translation>وسط</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2662"/>
        <source>Select Text Color</source>
        <translation>انتخاب رنگ متن</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2694"/>
        <source>Select Background Color</source>
        <translation>انتخاب رنگ پسزمينه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2828"/>
        <source>Deletion</source>
        <translation>حذف</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2946"/>
        <source>Tag(s) for this node</source>
        <translation>برچسب(های) اين شاخه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3202"/>
        <source>Select Document Font</source>
        <translation>انتخاب قلم متن</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3264"/>
        <source>Select Node Font</source>
        <translation>انتخاب قلم شاخه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3289"/>
        <source>Set Document Colors</source>
        <translation>تعيين رنگهای سند</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3299"/>
        <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
        <translation>اين رنگها برای شاخه‌های نو هستند.&lt;br&gt;ممکن است بر شاخه‌های موجود اثر نگذارند&lt;br&gt;اما توصيه می‌شود سند را دوباره باز کنيد.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3302"/>
        <source>Background color:</source>
        <translation>رنگ پسزمينه:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3308"/>
        <source>Text color:</source>
        <translation>رنگ متن:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4088"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation>تنها ۱۰۰۰ جايگزينی نخست رنگی شده‌اند.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4430"/>
        <location filename="../../fn.cpp" line="4609"/>
        <source>Scale to</source>
        <translation>تغيير اندازه به</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4434"/>
        <location filename="../../fn.cpp" line="4612"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4603"/>
        <source>Scale Image(s)</source>
        <translation>تغيير اندازه‌ی تصوير(ها)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4740"/>
        <source>untitled</source>
        <translation>بی‌نام</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4772"/>
        <source>Error</source>
        <translation>خطا</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4773"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;تصوير قابل ذخيره‌سازی نيست! امتحان مجدد؟&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4774"/>
        <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
&lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
        <translation>&lt;center&gt;شايد افزونه‌ی مناسبی (بعد از نقطه) انتخاب نکرده‌ايد&lt;/center&gt;
&lt;center&gt;يا اجازه‌ی نوشتن نداريد.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4806"/>
        <source>Save Image As...</source>
        <translation>ذخيره‌سازی تصوير به عنوان...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4861"/>
        <source>Insert Table</source>
        <translation>گذاشتن جدول</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4867"/>
        <source>Rows:</source>
        <translation>رديف:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4873"/>
        <source>Columns:</source>
        <translation>ستون:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5757"/>
        <source>Print Document</source>
        <translation>چاپ سند</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5763"/>
        <source>Printing completed.</source>
        <translation>چاپ انجام شد.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5765"/>
        <source>Printing in progress...</source>
        <translation>در حال چاپ کردن...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5784"/>
        <source>Export HTML</source>
        <translation>صدور به HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5789"/>
        <source>Export:</source>
        <translation>صدور:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5790"/>
        <source>&amp;Current node</source>
        <translation>شاخه‌ی فعلی</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5792"/>
        <source>With all &amp;sub-nodes</source>
        <translation>با همه‌ی زيرشاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5793"/>
        <source>&amp;All nodes</source>
        <translation>همه‌ی شاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5805"/>
        <source>Output file:</source>
        <translation>فايل خروجی:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5824"/>
        <source>Select path</source>
        <translation>انتخاب مسير</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5865"/>
        <source>Question</source>
        <translation>پرسش</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5866"/>
        <source>The file already exists.
Do you want to replace it?
</source>
        <translation>فايلی به همين نام وجود دارد.
آيا می‌خواهيد آن را جايگزين کنيد؟
</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6048"/>
        <source>Save HTML As...</source>
        <translation>ذخيره‌سازی HTML به عنوان...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6074"/>
        <source>Set Password</source>
        <translation>انتخاب گذرواژه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6083"/>
        <source>Type password</source>
        <translation>گذرواژه را تايپ کنيد</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6095"/>
        <source>Retype password</source>
        <translation>گذرواژه را دوباره تايپ کنيد</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6167"/>
        <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;گذرواژه‌ها فرق داشتند. امتحان مجدد؟&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6187"/>
        <location filename="../../fn.cpp" line="6195"/>
        <source>Enter Password</source>
        <translation>ورود گذرواژه</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6267"/>
        <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;گذرواژه نادرست بود. امتحان مجدد؟&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6309"/>
        <source>A lightweight notes manager</source>
        <translation>يک دفتر يادداشت سبک</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6310"/>
        <source>based on Qt</source>
        <translation>بر پايه‌ی Qt</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6311"/>
        <source>Author</source>
        <translation>نگارنده</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6313"/>
        <location filename="../../fn.cpp" line="6314"/>
        <source>About FeatherNotes</source>
        <translation>درباره‌ی FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6313"/>
        <source>Translators</source>
        <translation>مترجمان</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6497"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation>تنظيمها ← متن ← بررسی تلفظ را مشاهده کنيد!</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6513"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation>نياز به افزودن لغتنامه‌ی Hunspell داريد.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6518"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation>لغتنامه‌ی Hunspell وجود ندارد.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6526"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation>لغتنامه‌ی Hunspell همراه فايل ضميمه نيست.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6544"/>
        <location filename="../../fn.cpp" line="6559"/>
        <location filename="../../fn.cpp" line="6571"/>
        <source>No misspelling from text cursor.</source>
        <translation>لفظ نادرستی با شروع از نشانگر متنی وجود ندارد.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6583"/>
        <source>Spell Checking</source>
        <translation>بررسی تلفظ</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6312"/>
        <source>aka.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FeatherNotes::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="35"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>پاکسازی متن (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../lineedit.cpp" line="81"/>
        <source>Ctrl+K</source>
        <comment>Clear text</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>FeatherNotes::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>تنظيمها</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="27"/>
        <source>Window</source>
        <translation>پنجره</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="36"/>
        <source>Saves window size after closing
this dialog and also on exit.

Uncheck to set a fixed size!</source>
        <translation>يادآوری اندازه‌ی پنجره پس از بستن اين ديالوگ
و همچنين پيش از خروج.

برای تعيين اندازه‌ی ثابت، اين گزينه را خالی بگذاريد!</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="42"/>
        <source>Remember window &amp;size</source>
        <translation>يادآوری اندازه‌ی پنجره</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="51"/>
        <source>Start with this size: </source>
        <translation>با اين اندازه شروع کن: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="58"/>
        <location filename="../../prefDialog.ui" line="72"/>
        <source> px</source>
        <translation> پيکسل</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="97"/>
        <source>Saves tree width after closing
this dialog and also on exit.

Uncheck for a width ratio of 170/530.</source>
        <translation>پهنای بخش شاخه‌ها را پس از بستن اين ديالوگ
و همچنين پيش از خروج ذخيره می‌کند.

برای نسبت ثابت ۱۷۰/۵۳۰، اين گزينه را خالی بگذاريد.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="103"/>
        <source>Remember &amp;tree width</source>
        <translation>يادآوری پهنای بخش شاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>Saves position after closing
this dialog and also on exit.

This may not work correctly
with some window managers.</source>
        <translation>موقعيت پنجره را پس از بستن اين ديالوگ
و همچنين پيش از خروج ذخيره می‌کند.

اين تنظيم ممکن است با برخی از پنجره‌گردانها
درست کار نکند.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="117"/>
        <source>Save &amp;position</source>
        <translation>يادآوری موقعيت پنجره</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="124"/>
        <source>Decides whether a systray icon should be used.
If checked, the titlebar close button iconifies
the window to the systray instead of quitting.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>تعيين می‌کند که آيا برنامه بايد از جعبه‌ی وظايف استفاده کند.
اگر اتنخاب شود، دکمه‌ی بستن، روی نوار بالايی پنجره، باعث
خروج از برنامه نمی‌شود بلکه پنجره را به درون جعبه‌ی وظايف می‌برد.

برای فعال شدن، نيازمند شروع مجدد برنامه است.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="131"/>
        <source>Add to s&amp;ystray</source>
        <translation>افزودن به جعبه‌ی وظايف</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="156"/>
        <source>The command line option --tray
can be used instead of this.</source>
        <translation>خط فرمان --tray می‌تواند به جای اين گزينه به کار برده شود.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="160"/>
        <source>Start i&amp;conified to tray</source>
        <translation>شروع از درون جعبه‌ی وظايف</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="169"/>
        <source>Merge the tree view with its surroundings?</source>
        <translation>حذف پسزمينه‌ی بخش شاخه‌ها؟</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="172"/>
        <source>Transparent t&amp;ree view</source>
        <translation>پسزمينه‌ی شفاف برای بخش شاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="179"/>
        <source>By default, the active widget style determines
the size of toolbar icons.</source>
        <translation>بطور پيشفرض، ضخامت نوار ابزارها توسط برنامه‌ای
تعيين می‌شود که پنجره‌ها را رسم می‌کند.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="183"/>
        <source>Small toolbar icons</source>
        <translation>نوار ابزارهای نازک</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="190"/>
        <source>Do not show t&amp;oolbar</source>
        <translation>پنهان کردن نوار ابزارها</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="197"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation>اگر نوار منو پنهان شود، يک دکمه‌ی منو
روی نوار ابزارها ظاهر می‌گردد.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="201"/>
        <source>Do not show &amp;menubar</source>
        <translation>پنهان کردن نوار منو</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="228"/>
        <source>Text</source>
        <translation>متن</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="237"/>
        <source>&amp;Wrap lines by default</source>
        <translation>قالب‌بندی خطها به صورت پيشفرض</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="244"/>
        <source>Auto-&amp;indent by default</source>
        <translation>دندانه‌سازی به صورت پيشفرض</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="251"/>
        <source>This covers parentheses, braces, brackets and quotes.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>شامل پرانتز، کروشه، براکت و نقل قول می‌شود.

برای فعال شدن، نيازمند شروع مجدد برنامه است.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="256"/>
        <source>Auto-&amp;bracket</source>
        <translation>براکت خودکار</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="263"/>
        <source>A triple period is replaced with an ellipsis,
a double hyphen with a long dash, etc. while
the user is typing and under proper circumstances.</source>
        <translation>به صورت پيشفرض، هز سه نقطه با يک ellipsis و
هر دو خط تيره با يک خط تيره‌ی بلند جايگزين می‌شود.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>&amp;Replace some characters while typing</source>
        <translation>جايگزينی برخی از حرفها هنگام نوشتن</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="277"/>
        <location filename="../../prefDialog.ui" line="290"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation>برای چسباندن تاريخ و زمان بکار می‌رود.
برای استفاده از قالب پيشفرض، خالی بگذاريد.

پس از بستن اين ديالوگ اثر می‌کند.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="283"/>
        <source>Date and time format:</source>
        <translation>قالب تاريخ و زمان:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>&amp;Auto-save every</source>
        <translation>ذخيره‌سازی خودکار در هر</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="314"/>
        <source> minute(s)</source>
        <translation> دقيقه</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="348"/>
        <source>If this option is checked, the opened document will
be saved on exiting without prompt and without
showing a warning if saving is not possible.</source>
        <translation>اگر اين گزينه فعال شود، سندی که باز شده است،
بدون پرسش از کاربر و بدون هشدار درباره‌ی
عدم موفقيت احتمالی، هنگام خروج ذخيره می‌شود.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="353"/>
        <source>Save opened document on exiting</source>
        <translation>ذخيره‌سازی هنگام خروج</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="376"/>
        <source>Spell Checking</source>
        <translation>بررسی تلفظ</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="384"/>
        <location filename="../../prefDialog.ui" line="396"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation>لغتنامه‌ی Hunspell نامی دارد که شامل &quot;.dic&quot; می‌شود و همراه با فايل ضميمه‌ای می‌آيد که پسوند &quot;.aff&quot; دارد.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="389"/>
        <source>Hunspell dictionary path:</source>
        <translation>مسير لغتنامه‌ی Hunspell:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="408"/>
        <location filename="../../pref.cpp" line="647"/>
        <source>Add dictionary...</source>
        <translation>افزودن لغتنامه...</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Files</source>
        <translation>فايلها</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="452"/>
        <source>Start with the last opened file</source>
        <translation>شروع با آخرين فايل بازشده</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="464"/>
        <source>Number of recent files:</source>
        <translation>تعداد فايل‌های تازه:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="496"/>
        <source>Open recent files separately</source>
        <translation>باز کردن فايلهای تازه بطور جداگانه</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="503"/>
        <source>By default, all nodes are expanded on opening a document.</source>
        <translation>به طور پيشفرض، هنگامی که سندی باز می‌شود، همه‌ی شاخه‌هايش باز می‌شوند.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="506"/>
        <source>Remember expanded states of nodes</source>
        <translation>يادآوری حالت باز يا بسته‌ی شاخه‌ها</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="530"/>
        <source>Shortcuts</source>
        <translation>ميانبرها</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="549"/>
        <source>Action</source>
        <translation>اقدام</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="554"/>
        <source>Shortcut</source>
        <translation>ميانبر</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="562"/>
        <source>Default</source>
        <translation>پيشفرض</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="340"/>
        <location filename="../../pref.cpp" line="520"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation>هشدار: ميانبری مبهم تشخيض داده شد!</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="503"/>
        <source>The typed shortcut was reserved.</source>
        <translation>اين ميانبر برای کار ديگری کنار گذاشته شده است.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="618"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>شروع مجدد برنامه برای اعمال تغييرات لازم است.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="649"/>
        <source>Hunspell Dictionary Files</source>
        <translation>فايلهای لغتنامه‌ی Hunspell</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>واژه ناشناخته:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation>افزودن به لغتنامه</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>جايگزينی با:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>ناديده گرفتن يکباره</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>ناديده گرفتن همه</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>اصلاح يکباره</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation>اصلاح همه</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::helpDialog</name>
    <message>
        <location filename="../../helpDialog.ui" line="14"/>
        <source>Help</source>
        <translation>راهنما</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../domitem.cpp" line="100"/>
        <location filename="../../domitem.cpp" line="137"/>
        <source>New Node</source>
        <translation>شاخه‌ی نو</translation>
    </message>
</context>
</TS>
